@@ -26,7 +26,7 @@ class twitterParser(object):
             if not user: return
             try:
                 user=self.api.GetUser(user.strip())
-                self.users.append( { user.id : [ {}, self.api.GetFollowerIDs(user.id) , self.api.GetFriendIDs(user.id) ]} )
+                self.users.append( { user.id : [ user.AsDict(), self.api.GetFollowerIDs(user.id) , self.api.GetFriendIDs(user.id) ]} )
             except Exception, e:
                 print e.__class__
                 if "Rate limit" in e.message:
